@@ -44,6 +44,8 @@ describe 'nova::api' do
 
       it { is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_ensure('absent')}
 
+      it { is_expected.to contain_class('nova::availability_zone') }
+
       it 'configures various stuff' do
         is_expected.to contain_nova_config('wsgi/api_paste_config').with('value' => 'api-paste.ini')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with('value' => '0.0.0.0')
@@ -325,6 +327,18 @@ describe 'nova::api' do
 
   end
 
+  shared_examples 'nova-api on Debian' do
+    context 'with default parameters' do
+      it { is_expected.to contain_service('nova-api- metadata').with(
+        :name      => 'nova-api-metadata',
+        :ensure    => 'running',
+        :hasstatus => true,
+        :enable    => true,
+        :tag       => 'nova-service',
+      )}
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -344,6 +358,9 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
+      if facts[:os_package_type] == 'debian'
+        it_behaves_like 'nova-api on Debian'
+      end
     end
   end
 end
